jdk/test/java/net/httpclient/ProxyTest.java
changeset 46157 f3c2dcb8d8fe
parent 46138 5982afcbf9dc
--- a/jdk/test/java/net/httpclient/ProxyTest.java	Tue Aug 15 19:19:50 2017 -0700
+++ b/jdk/test/java/net/httpclient/ProxyTest.java	Wed Aug 16 10:55:05 2017 +0100
@@ -56,9 +56,12 @@
 
 /**
  * @test
  * @bug 8185852
  * @summary verifies that passing a proxy with an unresolved address does
  *          not cause  java.nio.channels.UnresolvedAddressException
  * @modules jdk.incubator.httpclient
  * @library /lib/testlibrary/
  * @build jdk.testlibrary.SimpleSSLContext ProxyTest
@@ -111,7 +114,7 @@
         server.start();
         try {
             test(server, HttpClient.Version.HTTP_1_1);
-            // test(server, HttpClient.Version.HTTP_2);
+            test(server, HttpClient.Version.HTTP_2);
         } finally {
             server.stop(0);
             System.out.println("Server stopped");
@@ -56,9 +56,12 @@
 /**
  * @test
- * @bug 8185852
- * @summary verifies that passing a proxy with an unresolved address does
- *          not cause  java.nio.channels.UnresolvedAddressException
+ * @bug 8185852 8181422
+ * @summary Verifies that passing a proxy with an unresolved address does
+ *          not cause java.nio.channels.UnresolvedAddressException.
+ *          Verifies that downgrading from HTTP/2 to HTTP/1.1 works through
+ *          an SSL Tunnel connection when the client is HTTP/2 and the server
+ *          and proxy are HTTP/1.1
  * @modules jdk.incubator.httpclient
  * @library /lib/testlibrary/